/*
 * Phone.h
 * Header file including phone, linked list node, and tower
 * representations.
 *
 *  Created on: Nov 5, 2014
 *      Author: David Monismith
 */


#ifndef PHONE_H
#define PHONE_H

/*
 * Structure representing a cell phone.
 * Includes the phone's rank, associated tower rank, and
 * location in degrees (theta).
 */
struct phone
{
  int phoneRank;
  int associatedTower;
  double theta;
};

typedef struct phone phone;

/*
 * Structure representing a linked list node containing a pointer
 * to a phone.
 */
struct node
{
  phone * p;
  struct node * next;
};

typedef struct node node;

/*
 * Structure representing a tower.  This contains the tower's rank,
 * the rank of the next tower, the location of the tower (center
 * degrees), the starting point of the tower's transmit radius
 * (start degrees), the ending point of the tower's transmit
 * radius in degrees (end degrees), and a list of phones associated
 * with this tower.
 */
struct tower
{
  int towerId;
  int nextTowerId;
  double towerCenterDegrees;
  double towerStartDegrees;
  double towerEndDegrees;
  node * phoneList;
};

typedef struct tower tower;

/* Function prototypes */

int isTower(int, int);
int inRadius(phone *, struct tower *);
double getTowerDistance(phone *, struct tower *);
int isPhone(int, int);

#endif
