#include "Phone.h"
#include <math.h>
#include <stdio.h>

/***********************************************
 * Function: isPhone                           *
 * Parameters: rank - the rank of this process *
 * numTowers - the number of cell towers used  *
 * in the simulation                           *
 *                                             *
 * Returns true if the calling process is a    *
 * phone by checking that the rank is greater  *
 * than or equal to the number of towers.      *
 ***********************************************/

int isPhone(int rank, int numTowers)
{
  if(rank - numTowers >= 0)
    return 1;
  return 0;
}

/***********************************************
 * Function: isTower                           *
 * Parameters: rank - the rank of this process *
 * numTowers - the number of cell towers used  *
 * in the simulation                           *
 *                                             *
 * Returns true if the calling process is a    *
 * tower by checking that the rank is less     *
 * than or equal to the number of towers.      *
 ***********************************************/

int isTower(int rank, int numTowers)
{
  if(rank < numTowers)
    return 1;
  return 0;
}

/***********************************************
 * Function: getTowerDistance                  *
 * Parameters: myPhone - pointer to a phone    *
 * myTower - pointer to a tower associated     *
 * with myPhone.                               *
 *                                             *
 * Returns the distance between the myTower and*
 * myPhone in degrees.                         *
 ***********************************************/

double getTowerDistance(phone * myPhone, tower * myTower)
{
  return fabs(myPhone->theta - myTower->towerCenterDegrees);
}


/***********************************************
 * Function: inRadius                          *
 * Parameters: myPhone - pointer to a phone    *
 * myTower - pointer to a tower associated     *
 * with myPhone.                               *
 *                                             *
 * Returns true if the phone is within the     *
 * radius of the tower by comparing the        *
 * location of the phone in degrees to the     *
 * location of the tower in degrees.           *
 ***********************************************/

int inRadius(phone * myPhone, tower * myTower)
{
  //If in tower radius area return true.
  //printf("tstart: %lf <= theta: %lf <= tend: %lf\n", myTower->towerStartDegrees, myPhone->theta, myTower->towerEndDegrees);
  if(myTower->towerStartDegrees <= myPhone->theta && myPhone->theta <= myTower->towerEndDegrees )
    return 1;

  return 0;
}

